from ._AccessSchedule import *
from ._ComponentState import *
from ._ConformanceStatus import *
from ._ConformanceUavStatus import *
from ._Constants import *
from ._DigitalEyeStatus import *
from ._Flightpath import *
from ._Flightpoint import *
from ._GNSSPosition import *
from ._GNSSState import *
from ._IMUValue import *
from ._MASDefinition import *
from ._MGSDefinition import *
from ._MGSStatus import *
from ._MVSControl import *
from ._Metric import *
from ._Object import *
from ._ObjectList import *
from ._Pole import *
from ._PolePose import *
from ._Position import *
from ._Sensor import *
from ._SensorPose import *
from ._State import *
from ._SystemCommand import *
from ._SystemConfiguration import *
from ._SystemNotification import *
from ._SystemState import *
from ._SystemTransition import *
from ._TimeSlot import *
from ._UavExtReport import *
from ._UavExtReportList import *
from ._UavFlightData import *
from ._UavGeneralMsg import *
from ._UavIntReport import *
from ._UavIntReportList import *
from ._UavState import *
from ._UavStateList import *
from ._Zone import *
from ._ZoneObjectStatus import *



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Metric.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class Metric(genpy.Message):
  _md5sum = "bc6ccc4a57f61779c8eaae61e9f422e0"
  _type = "digitaleye_msgs/Metric"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value
"""
  __slots__ = ['name','value']
  _slot_types = ['string','string']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       name,value

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Metric, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.name is None:
        self.name = ''
      if self.value is None:
        self.value = ''
    else:
      self.name = ''
      self.value = ''

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.name
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.value
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.name = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.name = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.value = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.value = str[start:end]
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.name
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.value
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.name = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.name = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.value = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.value = str[start:end]
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/ZoneObjectStatus.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import genpy

class ZoneObjectStatus(genpy.Message):
  _md5sum = "8772b83ae4bd9c1cd4909050418563b0"
  _type = "digitaleye_msgs/ZoneObjectStatus"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Status of the object within the specified zone

# identifier of the zone the object is in
uint32 zone_id

# whether or not the object is allowed in the zone
bool allowed

# time the object was first detected in this zone
# (ros timestamp in epoch time)
time first_detected

# time the object was last detected in this zone
# (ros timestamp in epoch time)
time last_detected
"""
  __slots__ = ['zone_id','allowed','first_detected','last_detected']
  _slot_types = ['uint32','bool','time','time']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       zone_id,allowed,first_detected,last_detected

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(ZoneObjectStatus, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.zone_id is None:
        self.zone_id = 0
      if self.allowed is None:
        self.allowed = False
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
    else:
      self.zone_id = 0
      self.allowed = False
      self.first_detected = genpy.Time()
      self.last_detected = genpy.Time()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_IB4I().pack(_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
      end = 0
      _x = self
      start = end
      end += 21
      (_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs,) = _get_struct_IB4I().unpack(str[start:end])
      self.allowed = bool(self.allowed)
      self.first_detected.canon()
      self.last_detected.canon()
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_IB4I().pack(_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
      end = 0
      _x = self
      start = end
      end += 21
      (_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs,) = _get_struct_IB4I().unpack(str[start:end])
      self.allowed = bool(self.allowed)
      self.first_detected.canon()
      self.last_detected.canon()
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_IB4I = None
def _get_struct_IB4I():
    global _struct_IB4I
    if _struct_IB4I is None:
        _struct_IB4I = struct.Struct("<IB4I")
    return _struct_IB4I



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Object.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import genpy
import geometry_msgs.msg
import std_msgs.msg
import visualization_msgs.msg

class Object(genpy.Message):
  _md5sum = "50a51e88bc1d873cad22eaf4e5964098"
  _type = "digitaleye_msgs/Object"
  _has_header = True  # flag to mark the presence of a Header object
  _full_text = """# Description of an object in the Monitored Space

# information on the time at which the object
# was reported (epoch time) and its reference frame
std_msgs/Header header

# id assigned to the reported object
uint64 object_id

# list of ID(s) of reported object(s) which
# constitute it (if fused)
uint64[] fused_ids

# coordinates of the object’s estimated position
# in the local reference frame (meters)
geometry_msgs/Point position

# 3D covariance of the object position, represents the quality
# of the position estimate, higher covariances mean
# a worse estimate. XX, XY, XZ, YX, YY, YZ, ZX, ZY, ZZ
float32[9] pos_covariance

# estimated accuracy radius of object's position (meters)
float32 accuracy

# estimated velocity of the object (m/s)
geometry_msgs/Vector3 velocity

# estimated acceleration of the object (m/s2)
geometry_msgs/Accel acceleration

# estimated size of the object (meters)
float32 size

# object’s category
# e.g. Personnel, Package, Passenger, UAV, etc.
string classification

# list of zone(s) in which the object is
ZoneObjectStatus[] zones

# Object visualisation marker
visualization_msgs/Marker bounding_cylinder

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z

================================================================================
MSG: geometry_msgs/Vector3
# This represents a vector in free space. 
# It is only meant to represent a direction. Therefore, it does not
# make sense to apply a translation to it (e.g., when applying a 
# generic rigid transformation to a Vector3, tf2 will only apply the
# rotation). If you want your data to be translatable too, use the
# geometry_msgs/Point message instead.

float64 x
float64 y
float64 z
================================================================================
MSG: geometry_msgs/Accel
# This expresses acceleration in free space broken into its linear and angular parts.
Vector3  linear
Vector3  angular

================================================================================
MSG: digitaleye_msgs/ZoneObjectStatus
# Status of the object within the specified zone

# identifier of the zone the object is in
uint32 zone_id

# whether or not the object is allowed in the zone
bool allowed

# time the object was first detected in this zone
# (ros timestamp in epoch time)
time first_detected

# time the object was last detected in this zone
# (ros timestamp in epoch time)
time last_detected

================================================================================
MSG: visualization_msgs/Marker
# See http://www.ros.org/wiki/rviz/DisplayTypes/Marker and http://www.ros.org/wiki/rviz/Tutorials/Markers%3A%20Basic%20Shapes for more information on using this message with rviz

uint8 ARROW=0
uint8 CUBE=1
uint8 SPHERE=2
uint8 CYLINDER=3
uint8 LINE_STRIP=4
uint8 LINE_LIST=5
uint8 CUBE_LIST=6
uint8 SPHERE_LIST=7
uint8 POINTS=8
uint8 TEXT_VIEW_FACING=9
uint8 MESH_RESOURCE=10
uint8 TRIANGLE_LIST=11

uint8 ADD=0
uint8 MODIFY=0
uint8 DELETE=2
uint8 DELETEALL=3

Header header                        # header for time/frame information
string ns                            # Namespace to place this object in... used in conjunction with id to create a unique name for the object
int32 id 		                         # object ID useful in conjunction with the namespace for manipulating and deleting the object later
int32 type 		                       # Type of object
int32 action 	                       # 0 add/modify an object, 1 (deprecated), 2 deletes an object, 3 deletes all objects
geometry_msgs/Pose pose                 # Pose of the object
geometry_msgs/Vector3 scale             # Scale of the object 1,1,1 means default (usually 1 meter square)
std_msgs/ColorRGBA color             # Color [0.0-1.0]
duration lifetime                    # How long the object should last before being automatically deleted.  0 means forever
bool frame_locked                    # If this marker should be frame-locked, i.e. retransformed into its frame every timestep

#Only used if the type specified has some use for them (eg. POINTS, LINE_STRIP, ...)
geometry_msgs/Point[] points
#Only used if the type specified has some use for them (eg. POINTS, LINE_STRIP, ...)
#number of colors must either be 0 or equal to the number of points
#NOTE: alpha is not yet used
std_msgs/ColorRGBA[] colors

# NOTE: only used for text markers
string text

# NOTE: only used for MESH_RESOURCE markers
string mesh_resource
bool mesh_use_embedded_materials

================================================================================
MSG: geometry_msgs/Pose
# A representation of pose in free space, composed of position and orientation. 
Point position
Quaternion orientation

================================================================================
MSG: geometry_msgs/Quaternion
# This represents an orientation in free space in quaternion form.

float64 x
float64 y
float64 z
float64 w

================================================================================
MSG: std_msgs/ColorRGBA
float32 r
float32 g
float32 b
float32 a
"""
  __slots__ = ['header','object_id','fused_ids','position','pos_covariance','accuracy','velocity','acceleration','size','classification','zones','bounding_cylinder']
  _slot_types = ['std_msgs/Header','uint64','uint64[]','geometry_msgs/Point','float32[9]','float32','geometry_msgs/Vector3','geometry_msgs/Accel','float32','string','digitaleye_msgs/ZoneObjectStatus[]','visualization_msgs/Marker']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       header,object_id,fused_ids,position,pos_covariance,accuracy,velocity,acceleration,size,classification,zones,bounding_cylinder

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Object, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.object_id is None:
        self.object_id = 0
      if self.fused_ids is None:
        self.fused_ids = []
      if self.position is None:
        self.position = geometry_msgs.msg.Point()
      if self.pos_covariance is None:
        self.pos_covariance = [0.] * 9
      if self.accuracy is None:
        self.accuracy = 0.
      if self.velocity is None:
        self.velocity = geometry_msgs.msg.Vector3()
      if self.acceleration is None:
        self.acceleration = geometry_msgs.msg.Accel()
      if self.size is None:
        self.size = 0.
      if self.classification is None:
        self.classification = ''
      if self.zones is None:
        self.zones = []
      if self.bounding_cylinder is None:
        self.bounding_cylinder = visualization_msgs.msg.Marker()
    else:
      self.header = std_msgs.msg.Header()
      self.object_id = 0
      self.fused_ids = []
      self.position = geometry_msgs.msg.Point()
      self.pos_covariance = [0.] * 9
      self.accuracy = 0.
      self.velocity = geometry_msgs.msg.Vector3()
      self.acceleration = geometry_msgs.msg.Accel()
      self.size = 0.
      self.classification = ''
      self.zones = []
      self.bounding_cylinder = visualization_msgs.msg.Marker()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.object_id
      buff.write(_get_struct_Q().pack(_x))
      length = len(self.fused_ids)
      buff.write(_struct_I.pack(length))
      pattern = '<%sQ'%length
      buff.write(struct.Struct(pattern).pack(*self.fused_ids))
      _x = self
      buff.write(_get_struct_3d().pack(_x.position.x, _x.position.y, _x.position.z))
      buff.write(_get_struct_9f().pack(*self.pos_covariance))
      _x = self
      buff.write(_get_struct_f9df().pack(_x.accuracy, _x.velocity.x, _x.velocity.y, _x.velocity.z, _x.acceleration.linear.x, _x.acceleration.linear.y, _x.acceleration.linear.z, _x.acceleration.angular.x, _x.acceleration.angular.y, _x.acceleration.angular.z, _x.size))
      _x = self.classification
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.zones)
      buff.write(_struct_I.pack(length))
      for val1 in self.zones:
        _x = val1
        buff.write(_get_struct_IB().pack(_x.zone_id, _x.allowed))
        _v1 = val1.first_detected
        _x = _v1
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _v2 = val1.last_detected
        _x = _v2
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
      _x = self
      buff.write(_get_struct_3I().pack(_x.bounding_cylinder.header.seq, _x.bounding_cylinder.header.stamp.secs, _x.bounding_cylinder.header.stamp.nsecs))
      _x = self.bounding_cylinder.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.ns
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_3i10d4f2iB().pack(_x.bounding_cylinder.id, _x.bounding_cylinder.type, _x.bounding_cylinder.action, _x.bounding_cylinder.pose.position.x, _x.bounding_cylinder.pose.position.y, _x.bounding_cylinder.pose.position.z, _x.bounding_cylinder.pose.orientation.x, _x.bounding_cylinder.pose.orientation.y, _x.bounding_cylinder.pose.orientation.z, _x.bounding_cylinder.pose.orientation.w, _x.bounding_cylinder.scale.x, _x.bounding_cylinder.scale.y, _x.bounding_cylinder.scale.z, _x.bounding_cylinder.color.r, _x.bounding_cylinder.color.g, _x.bounding_cylinder.color.b, _x.bounding_cylinder.color.a, _x.bounding_cylinder.lifetime.secs, _x.bounding_cylinder.lifetime.nsecs, _x.bounding_cylinder.frame_locked))
      length = len(self.bounding_cylinder.points)
      buff.write(_struct_I.pack(length))
      for val1 in self.bounding_cylinder.points:
        _x = val1
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
      length = len(self.bounding_cylinder.colors)
      buff.write(_struct_I.pack(length))
      for val1 in self.bounding_cylinder.colors:
        _x = val1
        buff.write(_get_struct_4f().pack(_x.r, _x.g, _x.b, _x.a))
      _x = self.bounding_cylinder.text
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.mesh_resource
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.mesh_use_embedded_materials
      buff.write(_get_struct_B().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.position is None:
        self.position = geometry_msgs.msg.Point()
      if self.velocity is None:
        self.velocity = geometry_msgs.msg.Vector3()
      if self.acceleration is None:
        self.acceleration = geometry_msgs.msg.Accel()
      if self.zones is None:
        self.zones = None
      if self.bounding_cylinder is None:
        self.bounding_cylinder = visualization_msgs.msg.Marker()
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 8
      (self.object_id,) = _get_struct_Q().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      pattern = '<%sQ'%length
      start = end
      s = struct.Struct(pattern)
      end += s.size
      self.fused_ids = s.unpack(str[start:end])
      _x = self
      start = end
      end += 24
      (_x.position.x, _x.position.y, _x.position.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 36
      self.pos_covariance = _get_struct_9f().unpack(str[start:end])
      _x = self
      start = end
      end += 80
      (_x.accuracy, _x.velocity.x, _x.velocity.y, _x.velocity.z, _x.acceleration.linear.x, _x.acceleration.linear.y, _x.acceleration.linear.z, _x.acceleration.angular.x, _x.acceleration.angular.y, _x.acceleration.angular.z, _x.size,) = _get_struct_f9df().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.classification = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.classification = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.zones = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.ZoneObjectStatus()
        _x = val1
        start = end
        end += 5
        (_x.zone_id, _x.allowed,) = _get_struct_IB().unpack(str[start:end])
        val1.allowed = bool(val1.allowed)
        _v3 = val1.first_detected
        _x = _v3
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        _v4 = val1.last_detected
        _x = _v4
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        self.zones.append(val1)
      _x = self
      start = end
      end += 12
      (_x.bounding_cylinder.header.seq, _x.bounding_cylinder.header.stamp.secs, _x.bounding_cylinder.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.header.frame_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.ns = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.ns = str[start:end]
      _x = self
      start = end
      end += 117
      (_x.bounding_cylinder.id, _x.bounding_cylinder.type, _x.bounding_cylinder.action, _x.bounding_cylinder.pose.position.x, _x.bounding_cylinder.pose.position.y, _x.bounding_cylinder.pose.position.z, _x.bounding_cylinder.pose.orientation.x, _x.bounding_cylinder.pose.orientation.y, _x.bounding_cylinder.pose.orientation.z, _x.bounding_cylinder.pose.orientation.w, _x.bounding_cylinder.scale.x, _x.bounding_cylinder.scale.y, _x.bounding_cylinder.scale.z, _x.bounding_cylinder.color.r, _x.bounding_cylinder.color.g, _x.bounding_cylinder.color.b, _x.bounding_cylinder.color.a, _x.bounding_cylinder.lifetime.secs, _x.bounding_cylinder.lifetime.nsecs, _x.bounding_cylinder.frame_locked,) = _get_struct_3i10d4f2iB().unpack(str[start:end])
      self.bounding_cylinder.frame_locked = bool(self.bounding_cylinder.frame_locked)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.bounding_cylinder.points = []
      for i in range(0, length):
        val1 = geometry_msgs.msg.Point()
        _x = val1
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        self.bounding_cylinder.points.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.bounding_cylinder.colors = []
      for i in range(0, length):
        val1 = std_msgs.msg.ColorRGBA()
        _x = val1
        start = end
        end += 16
        (_x.r, _x.g, _x.b, _x.a,) = _get_struct_4f().unpack(str[start:end])
        self.bounding_cylinder.colors.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.text = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.text = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.mesh_resource = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.mesh_resource = str[start:end]
      start = end
      end += 1
      (self.bounding_cylinder.mesh_use_embedded_materials,) = _get_struct_B().unpack(str[start:end])
      self.bounding_cylinder.mesh_use_embedded_materials = bool(self.bounding_cylinder.mesh_use_embedded_materials)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.object_id
      buff.write(_get_struct_Q().pack(_x))
      length = len(self.fused_ids)
      buff.write(_struct_I.pack(length))
      pattern = '<%sQ'%length
      buff.write(self.fused_ids.tostring())
      _x = self
      buff.write(_get_struct_3d().pack(_x.position.x, _x.position.y, _x.position.z))
      buff.write(self.pos_covariance.tostring())
      _x = self
      buff.write(_get_struct_f9df().pack(_x.accuracy, _x.velocity.x, _x.velocity.y, _x.velocity.z, _x.acceleration.linear.x, _x.acceleration.linear.y, _x.acceleration.linear.z, _x.acceleration.angular.x, _x.acceleration.angular.y, _x.acceleration.angular.z, _x.size))
      _x = self.classification
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.zones)
      buff.write(_struct_I.pack(length))
      for val1 in self.zones:
        _x = val1
        buff.write(_get_struct_IB().pack(_x.zone_id, _x.allowed))
        _v5 = val1.first_detected
        _x = _v5
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _v6 = val1.last_detected
        _x = _v6
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
      _x = self
      buff.write(_get_struct_3I().pack(_x.bounding_cylinder.header.seq, _x.bounding_cylinder.header.stamp.secs, _x.bounding_cylinder.header.stamp.nsecs))
      _x = self.bounding_cylinder.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.ns
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_3i10d4f2iB().pack(_x.bounding_cylinder.id, _x.bounding_cylinder.type, _x.bounding_cylinder.action, _x.bounding_cylinder.pose.position.x, _x.bounding_cylinder.pose.position.y, _x.bounding_cylinder.pose.position.z, _x.bounding_cylinder.pose.orientation.x, _x.bounding_cylinder.pose.orientation.y, _x.bounding_cylinder.pose.orientation.z, _x.bounding_cylinder.pose.orientation.w, _x.bounding_cylinder.scale.x, _x.bounding_cylinder.scale.y, _x.bounding_cylinder.scale.z, _x.bounding_cylinder.color.r, _x.bounding_cylinder.color.g, _x.bounding_cylinder.color.b, _x.bounding_cylinder.color.a, _x.bounding_cylinder.lifetime.secs, _x.bounding_cylinder.lifetime.nsecs, _x.bounding_cylinder.frame_locked))
      length = len(self.bounding_cylinder.points)
      buff.write(_struct_I.pack(length))
      for val1 in self.bounding_cylinder.points:
        _x = val1
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
      length = len(self.bounding_cylinder.colors)
      buff.write(_struct_I.pack(length))
      for val1 in self.bounding_cylinder.colors:
        _x = val1
        buff.write(_get_struct_4f().pack(_x.r, _x.g, _x.b, _x.a))
      _x = self.bounding_cylinder.text
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.mesh_resource
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.bounding_cylinder.mesh_use_embedded_materials
      buff.write(_get_struct_B().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.position is None:
        self.position = geometry_msgs.msg.Point()
      if self.velocity is None:
        self.velocity = geometry_msgs.msg.Vector3()
      if self.acceleration is None:
        self.acceleration = geometry_msgs.msg.Accel()
      if self.zones is None:
        self.zones = None
      if self.bounding_cylinder is None:
        self.bounding_cylinder = visualization_msgs.msg.Marker()
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 8
      (self.object_id,) = _get_struct_Q().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      pattern = '<%sQ'%length
      start = end
      s = struct.Struct(pattern)
      end += s.size
      self.fused_ids = numpy.frombuffer(str[start:end], dtype=numpy.uint64, count=length)
      _x = self
      start = end
      end += 24
      (_x.position.x, _x.position.y, _x.position.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 36
      self.pos_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float32, count=9)
      _x = self
      start = end
      end += 80
      (_x.accuracy, _x.velocity.x, _x.velocity.y, _x.velocity.z, _x.acceleration.linear.x, _x.acceleration.linear.y, _x.acceleration.linear.z, _x.acceleration.angular.x, _x.acceleration.angular.y, _x.acceleration.angular.z, _x.size,) = _get_struct_f9df().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.classification = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.classification = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.zones = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.ZoneObjectStatus()
        _x = val1
        start = end
        end += 5
        (_x.zone_id, _x.allowed,) = _get_struct_IB().unpack(str[start:end])
        val1.allowed = bool(val1.allowed)
        _v7 = val1.first_detected
        _x = _v7
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        _v8 = val1.last_detected
        _x = _v8
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        self.zones.append(val1)
      _x = self
      start = end
      end += 12
      (_x.bounding_cylinder.header.seq, _x.bounding_cylinder.header.stamp.secs, _x.bounding_cylinder.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.header.frame_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.ns = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.ns = str[start:end]
      _x = self
      start = end
      end += 117
      (_x.bounding_cylinder.id, _x.bounding_cylinder.type, _x.bounding_cylinder.action, _x.bounding_cylinder.pose.position.x, _x.bounding_cylinder.pose.position.y, _x.bounding_cylinder.pose.position.z, _x.bounding_cylinder.pose.orientation.x, _x.bounding_cylinder.pose.orientation.y, _x.bounding_cylinder.pose.orientation.z, _x.bounding_cylinder.pose.orientation.w, _x.bounding_cylinder.scale.x, _x.bounding_cylinder.scale.y, _x.bounding_cylinder.scale.z, _x.bounding_cylinder.color.r, _x.bounding_cylinder.color.g, _x.bounding_cylinder.color.b, _x.bounding_cylinder.color.a, _x.bounding_cylinder.lifetime.secs, _x.bounding_cylinder.lifetime.nsecs, _x.bounding_cylinder.frame_locked,) = _get_struct_3i10d4f2iB().unpack(str[start:end])
      self.bounding_cylinder.frame_locked = bool(self.bounding_cylinder.frame_locked)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.bounding_cylinder.points = []
      for i in range(0, length):
        val1 = geometry_msgs.msg.Point()
        _x = val1
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        self.bounding_cylinder.points.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.bounding_cylinder.colors = []
      for i in range(0, length):
        val1 = std_msgs.msg.ColorRGBA()
        _x = val1
        start = end
        end += 16
        (_x.r, _x.g, _x.b, _x.a,) = _get_struct_4f().unpack(str[start:end])
        self.bounding_cylinder.colors.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.text = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.text = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.bounding_cylinder.mesh_resource = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.bounding_cylinder.mesh_resource = str[start:end]
      start = end
      end += 1
      (self.bounding_cylinder.mesh_use_embedded_materials,) = _get_struct_B().unpack(str[start:end])
      self.bounding_cylinder.mesh_use_embedded_materials = bool(self.bounding_cylinder.mesh_use_embedded_materials)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_3i10d4f2iB = None
def _get_struct_3i10d4f2iB():
    global _struct_3i10d4f2iB
    if _struct_3i10d4f2iB is None:
        _struct_3i10d4f2iB = struct.Struct("<3i10d4f2iB")
    return _struct_3i10d4f2iB
_struct_4f = None
def _get_struct_4f():
    global _struct_4f
    if _struct_4f is None:
        _struct_4f = struct.Struct("<4f")
    return _struct_4f
_struct_9f = None
def _get_struct_9f():
    global _struct_9f
    if _struct_9f is None:
        _struct_9f = struct.Struct("<9f")
    return _struct_9f
_struct_B = None
def _get_struct_B():
    global _struct_B
    if _struct_B is None:
        _struct_B = struct.Struct("<B")
    return _struct_B
_struct_IB = None
def _get_struct_IB():
    global _struct_IB
    if _struct_IB is None:
        _struct_IB = struct.Struct("<IB")
    return _struct_IB
_struct_Q = None
def _get_struct_Q():
    global _struct_Q
    if _struct_Q is None:
        _struct_Q = struct.Struct("<Q")
    return _struct_Q
_struct_f9df = None
def _get_struct_f9df():
    global _struct_f9df
    if _struct_f9df is None:
        _struct_f9df = struct.Struct("<f9df")
    return _struct_f9df



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GNSSState.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg

class GNSSState(genpy.Message):
  _md5sum = "2a19cfc0a45b3c854f06a83290eb612b"
  _type = "digitaleye_msgs/GNSSState"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Describes the current state of a GNSS receiver/measurement

# Fix type of the satellite
uint32 sat_fix

# Number of visible satellites
uint32 num_sats

#Reported source of corrections
uint32 corr_source

# Last available measurement from the GNSS receiver
digitaleye_msgs/GNSSPosition measurement

================================================================================
MSG: digitaleye_msgs/GNSSPosition
# Description of a GNSS position reading

# Reported latitude of the receiver
float32 latitude

# Reported longitude of the receiver
float32 longitude

# Reported altitude of the receiver (WGS-84 Ellipsoid)
float32 altitude

# Reported altitude of the receiver (Mean Sea Level)
float32 altitude_msl

# Reported vertical dilution of precision
float32 vDOP

# Reported horizontal dilution of precision
float32 hDOP
"""
  __slots__ = ['sat_fix','num_sats','corr_source','measurement']
  _slot_types = ['uint32','uint32','uint32','digitaleye_msgs/GNSSPosition']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       sat_fix,num_sats,corr_source,measurement

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GNSSState, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.sat_fix is None:
        self.sat_fix = 0
      if self.num_sats is None:
        self.num_sats = 0
      if self.corr_source is None:
        self.corr_source = 0
      if self.measurement is None:
        self.measurement = digitaleye_msgs.msg.GNSSPosition()
    else:
      self.sat_fix = 0
      self.num_sats = 0
      self.corr_source = 0
      self.measurement = digitaleye_msgs.msg.GNSSPosition()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_3I6f().pack(_x.sat_fix, _x.num_sats, _x.corr_source, _x.measurement.latitude, _x.measurement.longitude, _x.measurement.altitude, _x.measurement.altitude_msl, _x.measurement.vDOP, _x.measurement.hDOP))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.measurement is None:
        self.measurement = digitaleye_msgs.msg.GNSSPosition()
      end = 0
      _x = self
      start = end
      end += 36
      (_x.sat_fix, _x.num_sats, _x.corr_source, _x.measurement.latitude, _x.measurement.longitude, _x.measurement.altitude, _x.measurement.altitude_msl, _x.measurement.vDOP, _x.measurement.hDOP,) = _get_struct_3I6f().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_3I6f().pack(_x.sat_fix, _x.num_sats, _x.corr_source, _x.measurement.latitude, _x.measurement.longitude, _x.measurement.altitude, _x.measurement.altitude_msl, _x.measurement.vDOP, _x.measurement.hDOP))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.measurement is None:
        self.measurement = digitaleye_msgs.msg.GNSSPosition()
      end = 0
      _x = self
      start = end
      end += 36
      (_x.sat_fix, _x.num_sats, _x.corr_source, _x.measurement.latitude, _x.measurement.longitude, _x.measurement.altitude, _x.measurement.altitude_msl, _x.measurement.vDOP, _x.measurement.hDOP,) = _get_struct_3I6f().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3I6f = None
def _get_struct_3I6f():
    global _struct_3I6f
    if _struct_3I6f is None:
        _struct_3I6f = struct.Struct("<3I6f")
    return _struct_3I6f



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/SensorPose.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import geometry_msgs.msg

class SensorPose(genpy.Message):
  _md5sum = "91c546ba42164d05edd8e32ab5e5bc7a"
  _type = "digitaleye_msgs/SensorPose"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Pose of a PORTAL sensor

# Position of the pole
uint32 perception_id

# unique identifier of the sensor
# e.g. hardware serial number
string sensor_id

# type of sensor being described
# e.g. camera, LIDAR, etc.
uint32 type

# Position of the sensor w.r.t the pole it is on
geometry_msgs/Pose pose

# Orientation of the sensor w.r.t the pole it is on
float32 orientation

================================================================================
MSG: geometry_msgs/Pose
# A representation of pose in free space, composed of position and orientation. 
Point position
Quaternion orientation

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z

================================================================================
MSG: geometry_msgs/Quaternion
# This represents an orientation in free space in quaternion form.

float64 x
float64 y
float64 z
float64 w
"""
  __slots__ = ['perception_id','sensor_id','type','pose','orientation']
  _slot_types = ['uint32','string','uint32','geometry_msgs/Pose','float32']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       perception_id,sensor_id,type,pose,orientation

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(SensorPose, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.perception_id is None:
        self.perception_id = 0
      if self.sensor_id is None:
        self.sensor_id = ''
      if self.type is None:
        self.type = 0
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      if self.orientation is None:
        self.orientation = 0.
    else:
      self.perception_id = 0
      self.sensor_id = ''
      self.type = 0
      self.pose = geometry_msgs.msg.Pose()
      self.orientation = 0.

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.perception_id
      buff.write(_get_struct_I().pack(_x))
      _x = self.sensor_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_I7df().pack(_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.orientation))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      end = 0
      start = end
      end += 4
      (self.perception_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.sensor_id = str[start:end]
      _x = self
      start = end
      end += 64
      (_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.orientation,) = _get_struct_I7df().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.perception_id
      buff.write(_get_struct_I().pack(_x))
      _x = self.sensor_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_I7df().pack(_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.orientation))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      end = 0
      start = end
      end += 4
      (self.perception_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.sensor_id = str[start:end]
      _x = self
      start = end
      end += 64
      (_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.orientation,) = _get_struct_I7df().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_I7df = None
def _get_struct_I7df():
    global _struct_I7df
    if _struct_I7df is None:
        _struct_I7df = struct.Struct("<I7df")
    return _struct_I7df



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Constants.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class Constants(genpy.Message):
  _md5sum = "40a1207f9528f103b1cefc0c2bf4106a"
  _type = "digitaleye_msgs/Constants"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# STATE CONSTANTS
uint32 STATE_OFF=1000
uint32 STATE_STOP=1001
uint32 STATE_INIT=1002
uint32 STATE_SETUP=1003
uint32 STATE_CALIBRATING=1004
uint32 STATE_TRACKING=1005
uint32 STATE_EMERGENCY=1006

# STATUS CONSTANTS
uint32 STATUS_OFF=2000
uint32 STATUS_STARTING=2001
uint32 STATUS_HEALTHY=2002
uint32 STATUS_FAILED=2003

# SUBSYSTEM IDENTIFIERS
uint32 SYSTEM_DIGITALEYE=3000
uint32 SYSTEM_MACHINE_VISION=3001
uint32 SYSTEM_IOT_GATEWAY=3002
uint32 SYSTEM_DEMS=3003
uint32 SYSTEM_POSITION=3004
uint32 SYSTEM_C2=3005

# MICROSERVICE IDENTIFIERS
uint32 MICROSERVICE_SYSTEM_CONFIG=4000
uint32 MICROSERVICE_STATUS_MANAGER=4001
uint32 MICROSERVICE_MVC_ADAPTER=4002
uint32 MICROSERVICE_IOT_ADAPTER=4003
uint32 MICROSERVICE_ZONE_DEFINITION=4004
uint32 MICROSERVICE_LOGGER=4005
uint32 MICROSERVICE_SENSOR_FUSION=4006
uint32 MICROSERVICE_MGS_MONITORING=4007
uint32 MICROSERVICE_MGS_MANAGER=4008
uint32 MICROSERVICE_MVC_CAMERA_MANAGER=4009
uint32 MICROSERVICE_MVC_LIDAR_MANAGER=4010
uint32 MICROSERVICE_MVC_ZONE_MANAGER=4011
uint32 MICROSERVICE_POSITION_ADAPTER=4012
uint32 MICROSERVICE_C2_ADAPTER=4013
uint32 MICROSERVICE_FLIGHTPATH_MANAGER=4014
uint32 MICROSERVICE_UAV_MANAGER=4015
uint32 MICROSERVICE_UAV_CONFORMANCE=4016
uint32 MICROSERVICE_CALIBRATION_MANAGER=4017

# SENSOR TYPE IDENTIFIERS
uint32 SENSOR_CAMERA=5000
uint32 SENSOR_LIDAR=5001
uint32 SENSOR_LOCATOR=5002
uint32 SENSOR_RTK=5003
uint32 SENSOR_COMPASS=5004
uint32 SENSOR_RADAR=5005

# REFERENCE FRAMES
uint32 FRAME_GLOBAL=6000
uint32 FRAME_DIGITALEYE=6001

# POLE IDENTIFIERS
uint32 POLE_P1=7000
uint32 POLE_S1=7001
uint32 POLE_S2=7002
uint32 POLE_S3=7003
uint32 POLE_L1=7004

# POSITION ENGINE NODE IDENTIFIERS
uint32 POSENG_POLE_MANAGER=8000
uint32 POSENG_STREAMER=8001
uint32 POSENG_SOLVER=8002
uint32 POSENG_SAMPLER=8003
uint32 POSENG_SURVEYOR=8004
uint32 POSENG_PORT=13013

# GNSS STATES
uint32 GNSS_NO_FIX=8100
uint32 GNSS_TIME_FLOAT=8101
uint32 GNSS_TIME_FIX=8102
uint32 GNSS_DEAD_FLOAT=8103
uint32 GNSS_DEAD_FIX=8104
uint32 GNSS_GPS_DEAD_FLOAT=8105
uint32 GNSS_GPS_DEAD_FIX=8106
uint32 GNSS_2D_FLOAT=8107
uint32 GNSS_2D_FIX=8108
uint32 GNSS_3D_FLOAT=8109
uint32 GNSS_3D_FIX=8110
uint32 GNSS_RTK_FLOAT=8111
uint32 GNSS_RTK_FIX=8112

# CORRECTION SOURCE
uint32 GNSS_NO_CORR=8200
uint32 GNSS_BASE_CORR=8201
uint32 GNSS_NTRIP_CORR=8202

# UAV IDENTIFIERS
uint32 UAV_UOBX1=8100
uint32 UAV_UOBX2=8101

# NOTIFICATION PRIORITIES
uint32 NOTIFICATION_INFO=9000
uint32 NOTIFICATION_IMPORTANT=9001
uint32 NOTIFICATION_CRITICAL=9002

# UAV MESSAGES
uint32 UAV_BOOKED=9100
uint32 UAV_C2_HANDOVER_BEGIN=9101
uint32 UAV_DEYE_HANDOVER_OK=9102
uint32 UAV_C2_HANDOVER_COMPLETE=9103
uint32 UAV_HOLD=9104
uint32 UAV_EXIT=9106

# CONFORMANCE STATUS
uint32 CONF_KO_UNKNOWN=9200
uint32 CONF_KO_AIR_ENTRY=9201
uint32 CONF_KO_GROUND_ENTRY=9202
uint32 CONF_KO_FLIGHTPATH=9203
uint32 CONF_OK_AIR_ENTRY=9204
uint32 CONF_OK_GROUND_ENTRY=9205
uint32 CONF_OK_FLIGHTPATH=9206
uint32 CONF_READY_TO_LAND=9207
uint32 CONF_READY_TO_FLY_OUT=9208

# UAV STATE
uint32 UAV_ST_UNKNOWN=9300
uint32 UAV_ST_NOT_READY=9301
uint32 UAV_ST_READY_TO=9302 # READY TO TAKE-OFF
uint32 UAV_ST_TAKING_OFF=9303
uint32 UAV_ST_FLYING=9304
uint32 UAV_ST_HELD=9305
uint32 UAV_ST_LANDING=9306

# METRICS DICTIONARY
string REALSENSE_DEPTH_PROJECTOR_TEMPERATURE = Depth Projector Temp.
string REALSENSE_DEPTH_ASIC_TEMPERATURE = Depth ASIC Temp.
string REALSENSE_DEPTH_FRAME_DROPS = Depth Frame Drops

string CPU1_BOARD_USAGE = CPU1 Usage%
string CPU2_BOARD_USAGE = CPU2 Usage%
string CPU3_BOARD_USAGE = CPU3 Usage%
string CPU4_BOARD_USAGE = CPU4 Usage%
string CPU5_BOARD_USAGE = CPU5 Usage%
string CPU6_BOARD_USAGE = CPU6 Usage%

string GPU_BOARD_USAGE = GPU Usage%

string JETSON_POWER_MODE =      Jetson Power Mode
string JETSON_RAM_USAGE =       Jetson RAM Usage
string JETSON_DISK_USAGE =      Jetson Disk Usage
string JETSON_FAN_SPEED =       Jetson Fan Speed
string JETSON_CPU_TEMPERATURE = Jetson CPU Temp.
string JETSON_GPU_TEMPERATURE = Jetson GPU Temp.
string JETSON_POWER_AVERAGE =   Jetson Power Avg.
string JETSON_UP_TIME =         Jetson Up Time

# Pole Metrics
string POLE_POSITION_LAT = Pole Latitude
string POLE_POSITION_LON = Pole Longitude
string POLE_POSITION_ALT = Pole Altitude
string POLE_POSITION_ALT_MSL = Pole Altitude (MSL)
string POLE_POSITION_VDOP = VDOP
string POLE_POSITION_HDOP = HDOP
string POLE_ORIENTATION = Pole Orientation
string POLE_NUM_SATS = No. of Satellites
string POLE_FIX_TYPE = GNSS Fix Type
string POLE_CORRECTIONS = RTK Corrections
string POLE_MODE = Operation Mode

# COMPASS
uint8 CMPS12_ADDRESS = 96
string COMPASS_MAGNETOMETER_X_VALUE = Magnetometer X
string COMPASS_MAGNETOMETER_Y_VALUE = Magnetometer Y
string COMPASS_MAGNETOMETER_Z_VALUE = Magnetometer Z
string COMPASS_ROLL_VALUE = Roll
string COMPASS_PITCH_VALUE = Pitch
string COMPASS_CALIBRATION_STATUS = Inertial sensor calibration Status

# UAV metrics
string UAV_STATE = UAV State
string UAV_TOLZ = UAV TOLZ
string UAV_NAME = UAV Name

# IOT metrics
string IOT_ISSUE = Issue

string QPE_CPU_LOAD = CPU Load
string QPE_LOSS_RATE = QPE Loss Rate
string QPE_NETWORK_LOSS_RATE = Network Loss Rate

string LOC_CONNECTION = Connection Status
string LOC_TEMP = Temperature

# SENSOR FUSION IDs

uint32 FASTLOOP_ID_START =     0
uint32 OBJECTS_ID_START =      100
uint32 PS_FASTLOOP_ID_START =      1000
uint32 PS_OBJECTS_ID_START =       1100

uint32 MVC_OBJECT_ID_NN_START = 1500
uint32 MVC_OBJECT_ID_CAMERA_START = 1600
uint32 MVC_OBJECT_ID_LIDAR_START =  1800

uint32 IOT_OBJECTS_ID_START =       2000
uint32 IOT_OBJECTS_ID_END =         3000
uint32 UAV_OBJECTS_ID_START =       10000

string SENSOR_FUSION_VALID_THRESHOLD = Set the threshold for an object to become valid
string SENSOR_FUSION_DELETE_THRESHOLD = Set the threshold for deleting an object
string SENSOR_FUSION_DISTANCE_THRESHOLD = Set the threshold for object distance association

string SENSOR_FUSION_DELETE_PERIOD = Set the period in secs for an object to be deleted
string SENSOR_FUSION_FILTER_FREQ = Set the frequency in Hz of the filtering
string SENSOR_FUSION_SYSTEM_TYPE = Set the type of the sensor fusion system

# MVS CONFIGURATION CONSTANTS
string START_MVC_AS_MAIN =      Start board as main Machine Vision Computer
string START_MVC_AS_SECONDARY = Start board as secondary Machine Vision Computer
string STOP_MVC =               Stop Machine Vision Computer

string CAMERA_EUCLIDEAN_FILTER_TOLERANCE =      Euclidean Segmentation tolerance for camera pointcloud
string CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES =    Minimum number of points for camera Euclidean Segmentation
string CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES =    Maximum number of points for camera Euclidean Segmentation
string CAMERA_OUTLIERS_REMOVAL_MEAN =           Mean for camera statistical noise removal Filter
string CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION =  Standard Deviation for camera statistical noise removal Filter

string CAMERA_SPATIAL_FILTER_ALPHA =        Alpha value for Realsense Spatial Edge Preserving filter
string CAMERA_SPATIAL_FILTER_DELTA =        Delta value for Realsense Spatial Edge Preserving filter
string CAMERA_SPATIAL_FILTER_MAGNITUDE =    Magnitude value for Realsense Spatial Edge Preserving filter
string CAMERA_SPATIAL_FILTER_HOLE_FILLING = Hole filling range value for Realsense Spatial Edge Preserving filter
string CAMERA_DECIMATION_FILTER_MAGNITUDE = Magnitude value for Realsense Decimation filter

string CAMERA_NEW_GROUND_TOLERANCE_VALUE =          Threshold for ground removal algorithm in camera
string CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE = Number of point clouds for ground removal algorithm in camera

string MVS_START_RECORDING = Start data recording
string MVS_STOP_RECORDING = Stop data recording
string MVS_PLAY_RECORDING = Play recorded data

string LIDAR_EUCLIDEAN_FILTER_TOLERANCE =      Euclidean Segmentation tolerance for lidar pointcloud
string LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES =    Minimum number of points for lidar Euclidean Segmentation
string LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES =    Maximum number of points for lidar Euclidean Segmentation
string LIDAR_OUTLIERS_REMOVAL_MEAN =           Mean for lidar statistical noise removal Filter
string LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION =  Standard Deviation for lidar statistical noise removal Filter

string LIDAR_NEW_GROUND_TOLERANCE_VALUE =          Threshold for ground removal algorithm in lidar
string LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE = Number of point clouds for ground removal algorithm in lidar

string MVS_NEW_NN_RECOGNITION_TH = Threshold for object recognition neural network

string SAVE_MVS_CONFIGURATION = Save MVS configuration parameters

string START_SENSOR_CALIBRATION = Start sensors calibration
string REJECT_SENSOR_CALIBRATION = Reject the sensors calibration

# PERCEPTION SYSTEM DEFAULT CONFIGURATION VALUES

float32 TOLERANCE_BOUNDING_CYLINDER = 1.2

float32 CAMERA_EUCLIDEAN_FILTER_TOLERANCE_DEFAULT = 0.2
float32 CAMERA_EUCLIDEAN_FILTER_TOLERANCE_MIN = 0.001
float32 CAMERA_EUCLIDEAN_FILTER_TOLERANCE_MAX = 1

float32 CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_DEFAULT = 350
float32 CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_MIN = 1
float32 CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_MAX = 300000

float32 CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_DEFAULT = 150000
float32 CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_MIN = 1
float32 CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_MAX = 300000

float32 CAMERA_OUTLIERS_REMOVAL_MEAN_DEFAULT = 50
float32 CAMERA_OUTLIERS_REMOVAL_MEAN_MIN = 0
float32 CAMERA_OUTLIERS_REMOVAL_MEAN_MAX = 100

float32 CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_DEFAULT = 1
float32 CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_MIN = 1
float32 CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_MAX = 10

float32 CAMERA_SPATIAL_FILTER_ALPHA_DEFAULT = 0.6
float32 CAMERA_SPATIAL_FILTER_ALPHA_MIN = 0.25
float32 CAMERA_SPATIAL_FILTER_ALPHA_MAX = 1

float32 CAMERA_SPATIAL_FILTER_DELTA_DEFAULT = 25
float32 CAMERA_SPATIAL_FILTER_DELTA_MIN = 1
float32 CAMERA_SPATIAL_FILTER_DELTA_MAX = 50

float32 CAMERA_SPATIAL_FILTER_MAGNITUDE_DEFAULT = 4
float32 CAMERA_SPATIAL_FILTER_MAGNITUDE_MIN = 1
float32 CAMERA_SPATIAL_FILTER_MAGNITUDE_MAX = 5

float32 CAMERA_SPATIAL_FILTER_HOLE_FILLING_DEFAULT = 3
float32 CAMERA_SPATIAL_FILTER_HOLE_FILLING_MIN = 0
float32 CAMERA_SPATIAL_FILTER_HOLE_FILLING_MAX = 5

float32 CAMERA_DECIMATION_FILTER_MAGNITUDE_DEFAULT = 3
float32 CAMERA_DECIMATION_FILTER_MAGNITUDE_MIN = 2
float32 CAMERA_DECIMATION_FILTER_MAGNITUDE_MAX = 8

float32 CAMERA_NEW_GROUND_TOLERANCE_VALUE_DEFAULT = 0.2
float32 CAMERA_NEW_GROUND_TOLERANCE_VALUE_MIN = 0.001
float32 CAMERA_NEW_GROUND_TOLERANCE_VALUE_MAX = 1

float32 CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_DEFAULT = 20
float32 CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MIN = 10
float32 CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MAX = 100


float32 LIDAR_EUCLIDEAN_FILTER_TOLERANCE_DEFAULT = 0.4
float32 LIDAR_EUCLIDEAN_FILTER_TOLERANCE_MIN = 0.001
float32 LIDAR_EUCLIDEAN_FILTER_TOLERANCE_MAX = 1

float32 LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_DEFAULT = 5
float32 LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_MIN = 1
float32 LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_MAX = 300000

float32 LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_DEFAULT = 100000
float32 LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_MIN = 1
float32 LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_MAX = 300000

float32 LIDAR_OUTLIERS_REMOVAL_MEAN_DEFAULT = 50
float32 LIDAR_OUTLIERS_REMOVAL_MEAN_MIN = 0
float32 LIDAR_OUTLIERS_REMOVAL_MEAN_MAX = 100

float32 LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_DEFAULT = 1
float32 LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_MIN = 1
float32 LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_MAX = 10

float32 LIDAR_NEW_GROUND_TOLERANCE_VALUE_DEFAULT = 0.2
float32 LIDAR_NEW_GROUND_TOLERANCE_VALUE_MIN = 0.001
float32 LIDAR_NEW_GROUND_TOLERANCE_VALUE_MAX = 1

float32 LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_DEFAULT = 20
float32 LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MIN = 10
float32 LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MAX = 100

float32 MVS_NEW_NN_RECOGNITION_TH_DEFAULT = 0.75
float32 MVS_NEW_NN_RECOGNITION_TH_MIN = 0.5
float32 MVS_NEW_NN_RECOGNITION_TH_MAX = 1.1
"""
  # Pseudo-constants
  STATE_OFF = 1000
  STATE_STOP = 1001
  STATE_INIT = 1002
  STATE_SETUP = 1003
  STATE_CALIBRATING = 1004
  STATE_TRACKING = 1005
  STATE_EMERGENCY = 1006
  STATUS_OFF = 2000
  STATUS_STARTING = 2001
  STATUS_HEALTHY = 2002
  STATUS_FAILED = 2003
  SYSTEM_DIGITALEYE = 3000
  SYSTEM_MACHINE_VISION = 3001
  SYSTEM_IOT_GATEWAY = 3002
  SYSTEM_DEMS = 3003
  SYSTEM_POSITION = 3004
  SYSTEM_C2 = 3005
  MICROSERVICE_SYSTEM_CONFIG = 4000
  MICROSERVICE_STATUS_MANAGER = 4001
  MICROSERVICE_MVC_ADAPTER = 4002
  MICROSERVICE_IOT_ADAPTER = 4003
  MICROSERVICE_ZONE_DEFINITION = 4004
  MICROSERVICE_LOGGER = 4005
  MICROSERVICE_SENSOR_FUSION = 4006
  MICROSERVICE_MGS_MONITORING = 4007
  MICROSERVICE_MGS_MANAGER = 4008
  MICROSERVICE_MVC_CAMERA_MANAGER = 4009
  MICROSERVICE_MVC_LIDAR_MANAGER = 4010
  MICROSERVICE_MVC_ZONE_MANAGER = 4011
  MICROSERVICE_POSITION_ADAPTER = 4012
  MICROSERVICE_C2_ADAPTER = 4013
  MICROSERVICE_FLIGHTPATH_MANAGER = 4014
  MICROSERVICE_UAV_MANAGER = 4015
  MICROSERVICE_UAV_CONFORMANCE = 4016
  MICROSERVICE_CALIBRATION_MANAGER = 4017
  SENSOR_CAMERA = 5000
  SENSOR_LIDAR = 5001
  SENSOR_LOCATOR = 5002
  SENSOR_RTK = 5003
  SENSOR_COMPASS = 5004
  SENSOR_RADAR = 5005
  FRAME_GLOBAL = 6000
  FRAME_DIGITALEYE = 6001
  POLE_P1 = 7000
  POLE_S1 = 7001
  POLE_S2 = 7002
  POLE_S3 = 7003
  POLE_L1 = 7004
  POSENG_POLE_MANAGER = 8000
  POSENG_STREAMER = 8001
  POSENG_SOLVER = 8002
  POSENG_SAMPLER = 8003
  POSENG_SURVEYOR = 8004
  POSENG_PORT = 13013
  GNSS_NO_FIX = 8100
  GNSS_TIME_FLOAT = 8101
  GNSS_TIME_FIX = 8102
  GNSS_DEAD_FLOAT = 8103
  GNSS_DEAD_FIX = 8104
  GNSS_GPS_DEAD_FLOAT = 8105
  GNSS_GPS_DEAD_FIX = 8106
  GNSS_2D_FLOAT = 8107
  GNSS_2D_FIX = 8108
  GNSS_3D_FLOAT = 8109
  GNSS_3D_FIX = 8110
  GNSS_RTK_FLOAT = 8111
  GNSS_RTK_FIX = 8112
  GNSS_NO_CORR = 8200
  GNSS_BASE_CORR = 8201
  GNSS_NTRIP_CORR = 8202
  UAV_UOBX1 = 8100
  UAV_UOBX2 = 8101
  NOTIFICATION_INFO = 9000
  NOTIFICATION_IMPORTANT = 9001
  NOTIFICATION_CRITICAL = 9002
  UAV_BOOKED = 9100
  UAV_C2_HANDOVER_BEGIN = 9101
  UAV_DEYE_HANDOVER_OK = 9102
  UAV_C2_HANDOVER_COMPLETE = 9103
  UAV_HOLD = 9104
  UAV_EXIT = 9106
  CONF_KO_UNKNOWN = 9200
  CONF_KO_AIR_ENTRY = 9201
  CONF_KO_GROUND_ENTRY = 9202
  CONF_KO_FLIGHTPATH = 9203
  CONF_OK_AIR_ENTRY = 9204
  CONF_OK_GROUND_ENTRY = 9205
  CONF_OK_FLIGHTPATH = 9206
  CONF_READY_TO_LAND = 9207
  CONF_READY_TO_FLY_OUT = 9208
  UAV_ST_UNKNOWN = 9300
  UAV_ST_NOT_READY = 9301
  UAV_ST_READY_TO = 9302
  UAV_ST_TAKING_OFF = 9303
  UAV_ST_FLYING = 9304
  UAV_ST_HELD = 9305
  UAV_ST_LANDING = 9306
  REALSENSE_DEPTH_PROJECTOR_TEMPERATURE = 'Depth Projector Temp.'
  REALSENSE_DEPTH_ASIC_TEMPERATURE = 'Depth ASIC Temp.'
  REALSENSE_DEPTH_FRAME_DROPS = 'Depth Frame Drops'
  CPU1_BOARD_USAGE = 'CPU1 Usage%'
  CPU2_BOARD_USAGE = 'CPU2 Usage%'
  CPU3_BOARD_USAGE = 'CPU3 Usage%'
  CPU4_BOARD_USAGE = 'CPU4 Usage%'
  CPU5_BOARD_USAGE = 'CPU5 Usage%'
  CPU6_BOARD_USAGE = 'CPU6 Usage%'
  GPU_BOARD_USAGE = 'GPU Usage%'
  JETSON_POWER_MODE = 'Jetson Power Mode'
  JETSON_RAM_USAGE = 'Jetson RAM Usage'
  JETSON_DISK_USAGE = 'Jetson Disk Usage'
  JETSON_FAN_SPEED = 'Jetson Fan Speed'
  JETSON_CPU_TEMPERATURE = 'Jetson CPU Temp.'
  JETSON_GPU_TEMPERATURE = 'Jetson GPU Temp.'
  JETSON_POWER_AVERAGE = 'Jetson Power Avg.'
  JETSON_UP_TIME = 'Jetson Up Time'
  POLE_POSITION_LAT = 'Pole Latitude'
  POLE_POSITION_LON = 'Pole Longitude'
  POLE_POSITION_ALT = 'Pole Altitude'
  POLE_POSITION_ALT_MSL = 'Pole Altitude (MSL)'
  POLE_POSITION_VDOP = 'VDOP'
  POLE_POSITION_HDOP = 'HDOP'
  POLE_ORIENTATION = 'Pole Orientation'
  POLE_NUM_SATS = 'No. of Satellites'
  POLE_FIX_TYPE = 'GNSS Fix Type'
  POLE_CORRECTIONS = 'RTK Corrections'
  POLE_MODE = 'Operation Mode'
  CMPS12_ADDRESS = 96
  COMPASS_MAGNETOMETER_X_VALUE = 'Magnetometer X'
  COMPASS_MAGNETOMETER_Y_VALUE = 'Magnetometer Y'
  COMPASS_MAGNETOMETER_Z_VALUE = 'Magnetometer Z'
  COMPASS_ROLL_VALUE = 'Roll'
  COMPASS_PITCH_VALUE = 'Pitch'
  COMPASS_CALIBRATION_STATUS = 'Inertial sensor calibration Status'
  UAV_STATE = 'UAV State'
  UAV_TOLZ = 'UAV TOLZ'
  UAV_NAME = 'UAV Name'
  IOT_ISSUE = 'Issue'
  QPE_CPU_LOAD = 'CPU Load'
  QPE_LOSS_RATE = 'QPE Loss Rate'
  QPE_NETWORK_LOSS_RATE = 'Network Loss Rate'
  LOC_CONNECTION = 'Connection Status'
  LOC_TEMP = 'Temperature'
  FASTLOOP_ID_START = 0
  OBJECTS_ID_START = 100
  PS_FASTLOOP_ID_START = 1000
  PS_OBJECTS_ID_START = 1100
  MVC_OBJECT_ID_NN_START = 1500
  MVC_OBJECT_ID_CAMERA_START = 1600
  MVC_OBJECT_ID_LIDAR_START = 1800
  IOT_OBJECTS_ID_START = 2000
  IOT_OBJECTS_ID_END = 3000
  UAV_OBJECTS_ID_START = 10000
  SENSOR_FUSION_VALID_THRESHOLD = 'Set the threshold for an object to become valid'
  SENSOR_FUSION_DELETE_THRESHOLD = 'Set the threshold for deleting an object'
  SENSOR_FUSION_DISTANCE_THRESHOLD = 'Set the threshold for object distance association'
  SENSOR_FUSION_DELETE_PERIOD = 'Set the period in secs for an object to be deleted'
  SENSOR_FUSION_FILTER_FREQ = 'Set the frequency in Hz of the filtering'
  SENSOR_FUSION_SYSTEM_TYPE = 'Set the type of the sensor fusion system'
  START_MVC_AS_MAIN = 'Start board as main Machine Vision Computer'
  START_MVC_AS_SECONDARY = 'Start board as secondary Machine Vision Computer'
  STOP_MVC = 'Stop Machine Vision Computer'
  CAMERA_EUCLIDEAN_FILTER_TOLERANCE = 'Euclidean Segmentation tolerance for camera pointcloud'
  CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES = 'Minimum number of points for camera Euclidean Segmentation'
  CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES = 'Maximum number of points for camera Euclidean Segmentation'
  CAMERA_OUTLIERS_REMOVAL_MEAN = 'Mean for camera statistical noise removal Filter'
  CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION = 'Standard Deviation for camera statistical noise removal Filter'
  CAMERA_SPATIAL_FILTER_ALPHA = 'Alpha value for Realsense Spatial Edge Preserving filter'
  CAMERA_SPATIAL_FILTER_DELTA = 'Delta value for Realsense Spatial Edge Preserving filter'
  CAMERA_SPATIAL_FILTER_MAGNITUDE = 'Magnitude value for Realsense Spatial Edge Preserving filter'
  CAMERA_SPATIAL_FILTER_HOLE_FILLING = 'Hole filling range value for Realsense Spatial Edge Preserving filter'
  CAMERA_DECIMATION_FILTER_MAGNITUDE = 'Magnitude value for Realsense Decimation filter'
  CAMERA_NEW_GROUND_TOLERANCE_VALUE = 'Threshold for ground removal algorithm in camera'
  CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE = 'Number of point clouds for ground removal algorithm in camera'
  MVS_START_RECORDING = 'Start data recording'
  MVS_STOP_RECORDING = 'Stop data recording'
  MVS_PLAY_RECORDING = 'Play recorded data'
  LIDAR_EUCLIDEAN_FILTER_TOLERANCE = 'Euclidean Segmentation tolerance for lidar pointcloud'
  LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES = 'Minimum number of points for lidar Euclidean Segmentation'
  LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES = 'Maximum number of points for lidar Euclidean Segmentation'
  LIDAR_OUTLIERS_REMOVAL_MEAN = 'Mean for lidar statistical noise removal Filter'
  LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION = 'Standard Deviation for lidar statistical noise removal Filter'
  LIDAR_NEW_GROUND_TOLERANCE_VALUE = 'Threshold for ground removal algorithm in lidar'
  LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE = 'Number of point clouds for ground removal algorithm in lidar'
  MVS_NEW_NN_RECOGNITION_TH = 'Threshold for object recognition neural network'
  SAVE_MVS_CONFIGURATION = 'Save MVS configuration parameters'
  START_SENSOR_CALIBRATION = 'Start sensors calibration'
  REJECT_SENSOR_CALIBRATION = 'Reject the sensors calibration'
  TOLERANCE_BOUNDING_CYLINDER = 1.2
  CAMERA_EUCLIDEAN_FILTER_TOLERANCE_DEFAULT = 0.2
  CAMERA_EUCLIDEAN_FILTER_TOLERANCE_MIN = 0.001
  CAMERA_EUCLIDEAN_FILTER_TOLERANCE_MAX = 1.0
  CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_DEFAULT = 350.0
  CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_MIN = 1.0
  CAMERA_EUCLIDEAN_FILTER_MIN_SAMPLES_MAX = 300000.0
  CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_DEFAULT = 150000.0
  CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_MIN = 1.0
  CAMERA_EUCLIDEAN_FILTER_MAX_SAMPLES_MAX = 300000.0
  CAMERA_OUTLIERS_REMOVAL_MEAN_DEFAULT = 50.0
  CAMERA_OUTLIERS_REMOVAL_MEAN_MIN = 0.0
  CAMERA_OUTLIERS_REMOVAL_MEAN_MAX = 100.0
  CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_DEFAULT = 1.0
  CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_MIN = 1.0
  CAMERA_OUTLIERS_REMOVAL_STD_DEVIATION_MAX = 10.0
  CAMERA_SPATIAL_FILTER_ALPHA_DEFAULT = 0.6
  CAMERA_SPATIAL_FILTER_ALPHA_MIN = 0.25
  CAMERA_SPATIAL_FILTER_ALPHA_MAX = 1.0
  CAMERA_SPATIAL_FILTER_DELTA_DEFAULT = 25.0
  CAMERA_SPATIAL_FILTER_DELTA_MIN = 1.0
  CAMERA_SPATIAL_FILTER_DELTA_MAX = 50.0
  CAMERA_SPATIAL_FILTER_MAGNITUDE_DEFAULT = 4.0
  CAMERA_SPATIAL_FILTER_MAGNITUDE_MIN = 1.0
  CAMERA_SPATIAL_FILTER_MAGNITUDE_MAX = 5.0
  CAMERA_SPATIAL_FILTER_HOLE_FILLING_DEFAULT = 3.0
  CAMERA_SPATIAL_FILTER_HOLE_FILLING_MIN = 0.0
  CAMERA_SPATIAL_FILTER_HOLE_FILLING_MAX = 5.0
  CAMERA_DECIMATION_FILTER_MAGNITUDE_DEFAULT = 3.0
  CAMERA_DECIMATION_FILTER_MAGNITUDE_MIN = 2.0
  CAMERA_DECIMATION_FILTER_MAGNITUDE_MAX = 8.0
  CAMERA_NEW_GROUND_TOLERANCE_VALUE_DEFAULT = 0.2
  CAMERA_NEW_GROUND_TOLERANCE_VALUE_MIN = 0.001
  CAMERA_NEW_GROUND_TOLERANCE_VALUE_MAX = 1.0
  CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_DEFAULT = 20.0
  CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MIN = 10.0
  CAMERA_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MAX = 100.0
  LIDAR_EUCLIDEAN_FILTER_TOLERANCE_DEFAULT = 0.4
  LIDAR_EUCLIDEAN_FILTER_TOLERANCE_MIN = 0.001
  LIDAR_EUCLIDEAN_FILTER_TOLERANCE_MAX = 1.0
  LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_DEFAULT = 5.0
  LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_MIN = 1.0
  LIDAR_EUCLIDEAN_FILTER_MIN_SAMPLES_MAX = 300000.0
  LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_DEFAULT = 100000.0
  LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_MIN = 1.0
  LIDAR_EUCLIDEAN_FILTER_MAX_SAMPLES_MAX = 300000.0
  LIDAR_OUTLIERS_REMOVAL_MEAN_DEFAULT = 50.0
  LIDAR_OUTLIERS_REMOVAL_MEAN_MIN = 0.0
  LIDAR_OUTLIERS_REMOVAL_MEAN_MAX = 100.0
  LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_DEFAULT = 1.0
  LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_MIN = 1.0
  LIDAR_OUTLIERS_REMOVAL_STD_DEVIATION_MAX = 10.0
  LIDAR_NEW_GROUND_TOLERANCE_VALUE_DEFAULT = 0.2
  LIDAR_NEW_GROUND_TOLERANCE_VALUE_MIN = 0.001
  LIDAR_NEW_GROUND_TOLERANCE_VALUE_MAX = 1.0
  LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_DEFAULT = 20.0
  LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MIN = 10.0
  LIDAR_NEW_NUMBER_CALIBRATION_CLOUDS_VALUE_MAX = 100.0
  MVS_NEW_NN_RECOGNITION_TH_DEFAULT = 0.75
  MVS_NEW_NN_RECOGNITION_TH_MIN = 0.5
  MVS_NEW_NN_RECOGNITION_TH_MAX = 1.1

  __slots__ = []
  _slot_types = []

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Constants, self).__init__(*args, **kwds)

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Sensor.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg
import sensor_msgs.msg
import std_msgs.msg

class Sensor(genpy.Message):
  _md5sum = "d718593cee4f32fdba7fc5123dafdd14"
  _type = "digitaleye_msgs/Sensor"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Description of a monitoring DigitalEye sensor
# and its properties

# unique identifier of the sensor
# e.g. hardware serial number
string sensor_id

# brand/model of sensor hardware
string model

# type of sensor being described
# e.g. camera, LIDAR, etc.
uint32 type

# position of the sensor in
# the DigitalEye’s local reference frame (meters)
geometry_msgs/Pose pose

# direction in which the sensor is facing
# with respect to the local frame’s x-axis
float32 azimuth

# resolution height of the image captured by the sensor
uint32 image_width

# resolution width of the image captured by the sensor
uint32 image_height

# frame rate of a vision sensor
uint32 frame_rate

# sensor’s current power level
float32 power

# Whether or not the sensor has been calibrated
bool calibrated

# current state of the sensor
digitaleye_msgs/State state

# Sensor inertial measurements
digitaleye_msgs/IMUValue imu

================================================================================
MSG: geometry_msgs/Pose
# A representation of pose in free space, composed of position and orientation. 
Point position
Quaternion orientation

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z

================================================================================
MSG: geometry_msgs/Quaternion
# This represents an orientation in free space in quaternion form.

float64 x
float64 y
float64 z
float64 w

================================================================================
MSG: digitaleye_msgs/State
# Details of a system’s status

# unique identifier of the system
# whose status is being reported
uint32 id

# system’s current state within the 
# DigitalEye state machine
uint32 state

# system’s substatus within the current state,
# unique to each system
uint32 status

# description of the system’s current state/status
string description

# timestamp indicating last change in state or status
# (epoch time in sec)
uint32 lastChange

# list of performance metrics associated with the
# current state
digitaleye_msgs/Metric[] metrics

================================================================================
MSG: digitaleye_msgs/Metric
# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value

================================================================================
MSG: digitaleye_msgs/IMUValue
# Description of an IMU value reading

# Imu heading
float32 heading

# Unique identifier of the sensor
# e.g. hardware serial number
string device_id

# Imu measurements
sensor_msgs/Imu imu

# Magenetometer readings
geometry_msgs/Vector3 magnetic_field

# Imu reading of roll
float32 roll

# Imu reading of pitch
float32 pitch

# Calibration status
bool deviceCalibrated

================================================================================
MSG: sensor_msgs/Imu
# This is a message to hold data from an IMU (Inertial Measurement Unit)
#
# Accelerations should be in m/s^2 (not in g's), and rotational velocity should be in rad/sec
#
# If the covariance of the measurement is known, it should be filled in (if all you know is the 
# variance of each measurement, e.g. from the datasheet, just put those along the diagonal)
# A covariance matrix of all zeros will be interpreted as "covariance unknown", and to use the
# data a covariance will have to be assumed or gotten from some other source
#
# If you have no estimate for one of the data elements (e.g. your IMU doesn't produce an orientation 
# estimate), please set element 0 of the associated covariance matrix to -1
# If you are interpreting this message, please check for a value of -1 in the first element of each 
# covariance matrix, and disregard the associated estimate.

Header header

geometry_msgs/Quaternion orientation
float64[9] orientation_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 angular_velocity
float64[9] angular_velocity_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 linear_acceleration
float64[9] linear_acceleration_covariance # Row major x, y z 

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: geometry_msgs/Vector3
# This represents a vector in free space. 
# It is only meant to represent a direction. Therefore, it does not
# make sense to apply a translation to it (e.g., when applying a 
# generic rigid transformation to a Vector3, tf2 will only apply the
# rotation). If you want your data to be translatable too, use the
# geometry_msgs/Point message instead.

float64 x
float64 y
float64 z"""
  __slots__ = ['sensor_id','model','type','pose','azimuth','image_width','image_height','frame_rate','power','calibrated','state','imu']
  _slot_types = ['string','string','uint32','geometry_msgs/Pose','float32','uint32','uint32','uint32','float32','bool','digitaleye_msgs/State','digitaleye_msgs/IMUValue']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       sensor_id,model,type,pose,azimuth,image_width,image_height,frame_rate,power,calibrated,state,imu

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Sensor, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.sensor_id is None:
        self.sensor_id = ''
      if self.model is None:
        self.model = ''
      if self.type is None:
        self.type = 0
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      if self.azimuth is None:
        self.azimuth = 0.
      if self.image_width is None:
        self.image_width = 0
      if self.image_height is None:
        self.image_height = 0
      if self.frame_rate is None:
        self.frame_rate = 0
      if self.power is None:
        self.power = 0.
      if self.calibrated is None:
        self.calibrated = False
      if self.state is None:
        self.state = digitaleye_msgs.msg.State()
      if self.imu is None:
        self.imu = digitaleye_msgs.msg.IMUValue()
    else:
      self.sensor_id = ''
      self.model = ''
      self.type = 0
      self.pose = geometry_msgs.msg.Pose()
      self.azimuth = 0.
      self.image_width = 0
      self.image_height = 0
      self.frame_rate = 0
      self.power = 0.
      self.calibrated = False
      self.state = digitaleye_msgs.msg.State()
      self.imu = digitaleye_msgs.msg.IMUValue()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.sensor_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.model
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_I7df3IfB3I().pack(_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated, _x.state.id, _x.state.state, _x.state.status))
      _x = self.state.description
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.state.lastChange
      buff.write(_get_struct_I().pack(_x))
      length = len(self.state.metrics)
      buff.write(_struct_I.pack(length))
      for val1 in self.state.metrics:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.imu.heading
      buff.write(_get_struct_f().pack(_x))
      _x = self.imu.device_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_3I().pack(_x.imu.imu.header.seq, _x.imu.imu.header.stamp.secs, _x.imu.imu.header.stamp.nsecs))
      _x = self.imu.imu.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_4d().pack(_x.imu.imu.orientation.x, _x.imu.imu.orientation.y, _x.imu.imu.orientation.z, _x.imu.imu.orientation.w))
      buff.write(_get_struct_9d().pack(*self.imu.imu.orientation_covariance))
      _x = self
      buff.write(_get_struct_3d().pack(_x.imu.imu.angular_velocity.x, _x.imu.imu.angular_velocity.y, _x.imu.imu.angular_velocity.z))
      buff.write(_get_struct_9d().pack(*self.imu.imu.angular_velocity_covariance))
      _x = self
      buff.write(_get_struct_3d().pack(_x.imu.imu.linear_acceleration.x, _x.imu.imu.linear_acceleration.y, _x.imu.imu.linear_acceleration.z))
      buff.write(_get_struct_9d().pack(*self.imu.imu.linear_acceleration_covariance))
      _x = self
      buff.write(_get_struct_3d2fB().pack(_x.imu.magnetic_field.x, _x.imu.magnetic_field.y, _x.imu.magnetic_field.z, _x.imu.roll, _x.imu.pitch, _x.imu.deviceCalibrated))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      if self.state is None:
        self.state = digitaleye_msgs.msg.State()
      if self.imu is None:
        self.imu = digitaleye_msgs.msg.IMUValue()
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.sensor_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.model = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.model = str[start:end]
      _x = self
      start = end
      end += 93
      (_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated, _x.state.id, _x.state.state, _x.state.status,) = _get_struct_I7df3IfB3I().unpack(str[start:end])
      self.calibrated = bool(self.calibrated)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.state.description = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.state.description = str[start:end]
      start = end
      end += 4
      (self.state.lastChange,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.state.metrics = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.state.metrics.append(val1)
      start = end
      end += 4
      (self.imu.heading,) = _get_struct_f().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.imu.device_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.imu.device_id = str[start:end]
      _x = self
      start = end
      end += 12
      (_x.imu.imu.header.seq, _x.imu.imu.header.stamp.secs, _x.imu.imu.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.imu.imu.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.imu.imu.header.frame_id = str[start:end]
      _x = self
      start = end
      end += 32
      (_x.imu.imu.orientation.x, _x.imu.imu.orientation.y, _x.imu.imu.orientation.z, _x.imu.imu.orientation.w,) = _get_struct_4d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.orientation_covariance = _get_struct_9d().unpack(str[start:end])
      _x = self
      start = end
      end += 24
      (_x.imu.imu.angular_velocity.x, _x.imu.imu.angular_velocity.y, _x.imu.imu.angular_velocity.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.angular_velocity_covariance = _get_struct_9d().unpack(str[start:end])
      _x = self
      start = end
      end += 24
      (_x.imu.imu.linear_acceleration.x, _x.imu.imu.linear_acceleration.y, _x.imu.imu.linear_acceleration.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.linear_acceleration_covariance = _get_struct_9d().unpack(str[start:end])
      _x = self
      start = end
      end += 33
      (_x.imu.magnetic_field.x, _x.imu.magnetic_field.y, _x.imu.magnetic_field.z, _x.imu.roll, _x.imu.pitch, _x.imu.deviceCalibrated,) = _get_struct_3d2fB().unpack(str[start:end])
      self.imu.deviceCalibrated = bool(self.imu.deviceCalibrated)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.sensor_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.model
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_I7df3IfB3I().pack(_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated, _x.state.id, _x.state.state, _x.state.status))
      _x = self.state.description
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.state.lastChange
      buff.write(_get_struct_I().pack(_x))
      length = len(self.state.metrics)
      buff.write(_struct_I.pack(length))
      for val1 in self.state.metrics:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.imu.heading
      buff.write(_get_struct_f().pack(_x))
      _x = self.imu.device_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_3I().pack(_x.imu.imu.header.seq, _x.imu.imu.header.stamp.secs, _x.imu.imu.header.stamp.nsecs))
      _x = self.imu.imu.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self
      buff.write(_get_struct_4d().pack(_x.imu.imu.orientation.x, _x.imu.imu.orientation.y, _x.imu.imu.orientation.z, _x.imu.imu.orientation.w))
      buff.write(self.imu.imu.orientation_covariance.tostring())
      _x = self
      buff.write(_get_struct_3d().pack(_x.imu.imu.angular_velocity.x, _x.imu.imu.angular_velocity.y, _x.imu.imu.angular_velocity.z))
      buff.write(self.imu.imu.angular_velocity_covariance.tostring())
      _x = self
      buff.write(_get_struct_3d().pack(_x.imu.imu.linear_acceleration.x, _x.imu.imu.linear_acceleration.y, _x.imu.imu.linear_acceleration.z))
      buff.write(self.imu.imu.linear_acceleration_covariance.tostring())
      _x = self
      buff.write(_get_struct_3d2fB().pack(_x.imu.magnetic_field.x, _x.imu.magnetic_field.y, _x.imu.magnetic_field.z, _x.imu.roll, _x.imu.pitch, _x.imu.deviceCalibrated))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.pose is None:
        self.pose = geometry_msgs.msg.Pose()
      if self.state is None:
        self.state = digitaleye_msgs.msg.State()
      if self.imu is None:
        self.imu = digitaleye_msgs.msg.IMUValue()
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.sensor_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.model = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.model = str[start:end]
      _x = self
      start = end
      end += 93
      (_x.type, _x.pose.position.x, _x.pose.position.y, _x.pose.position.z, _x.pose.orientation.x, _x.pose.orientation.y, _x.pose.orientation.z, _x.pose.orientation.w, _x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated, _x.state.id, _x.state.state, _x.state.status,) = _get_struct_I7df3IfB3I().unpack(str[start:end])
      self.calibrated = bool(self.calibrated)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.state.description = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.state.description = str[start:end]
      start = end
      end += 4
      (self.state.lastChange,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.state.metrics = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.state.metrics.append(val1)
      start = end
      end += 4
      (self.imu.heading,) = _get_struct_f().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.imu.device_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.imu.device_id = str[start:end]
      _x = self
      start = end
      end += 12
      (_x.imu.imu.header.seq, _x.imu.imu.header.stamp.secs, _x.imu.imu.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.imu.imu.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.imu.imu.header.frame_id = str[start:end]
      _x = self
      start = end
      end += 32
      (_x.imu.imu.orientation.x, _x.imu.imu.orientation.y, _x.imu.imu.orientation.z, _x.imu.imu.orientation.w,) = _get_struct_4d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.orientation_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
      _x = self
      start = end
      end += 24
      (_x.imu.imu.angular_velocity.x, _x.imu.imu.angular_velocity.y, _x.imu.imu.angular_velocity.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.angular_velocity_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
      _x = self
      start = end
      end += 24
      (_x.imu.imu.linear_acceleration.x, _x.imu.imu.linear_acceleration.y, _x.imu.imu.linear_acceleration.z,) = _get_struct_3d().unpack(str[start:end])
      start = end
      end += 72
      self.imu.imu.linear_acceleration_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
      _x = self
      start = end
      end += 33
      (_x.imu.magnetic_field.x, _x.imu.magnetic_field.y, _x.imu.magnetic_field.z, _x.imu.roll, _x.imu.pitch, _x.imu.deviceCalibrated,) = _get_struct_3d2fB().unpack(str[start:end])
      self.imu.deviceCalibrated = bool(self.imu.deviceCalibrated)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_3d2fB = None
def _get_struct_3d2fB():
    global _struct_3d2fB
    if _struct_3d2fB is None:
        _struct_3d2fB = struct.Struct("<3d2fB")
    return _struct_3d2fB
_struct_4d = None
def _get_struct_4d():
    global _struct_4d
    if _struct_4d is None:
        _struct_4d = struct.Struct("<4d")
    return _struct_4d
_struct_9d = None
def _get_struct_9d():
    global _struct_9d
    if _struct_9d is None:
        _struct_9d = struct.Struct("<9d")
    return _struct_9d
_struct_I7df3IfB3I = None
def _get_struct_I7df3IfB3I():
    global _struct_I7df3IfB3I
    if _struct_I7df3IfB3I is None:
        _struct_I7df3IfB3I = struct.Struct("<I7df3IfB3I")
    return _struct_I7df3IfB3I
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/SystemTransition.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class SystemTransition(genpy.Message):
  _md5sum = "eb5f2d8dabeb251d7829d6a30b42a34e"
  _type = "digitaleye_msgs/SystemTransition"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Request of a state change to a microservice

# state a microservice must be in to execute this transition
uint32 state_source

# state to which an eligible microservice should transition
uint32 state_destination
"""
  __slots__ = ['state_source','state_destination']
  _slot_types = ['uint32','uint32']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       state_source,state_destination

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(SystemTransition, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.state_source is None:
        self.state_source = 0
      if self.state_destination is None:
        self.state_destination = 0
    else:
      self.state_source = 0
      self.state_destination = 0

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_2I().pack(_x.state_source, _x.state_destination))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 8
      (_x.state_source, _x.state_destination,) = _get_struct_2I().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_2I().pack(_x.state_source, _x.state_destination))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 8
      (_x.state_source, _x.state_destination,) = _get_struct_2I().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/UavIntReportList.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg
import std_msgs.msg

class UavIntReportList(genpy.Message):
  _md5sum = "0059135ebfb1387c59850458a0b10bf6"
  _type = "digitaleye_msgs/UavIntReportList"
  _has_header = True  # flag to mark the presence of a Header object
  _full_text = """# List of internal generic UAV report(s)

# information on the time at which report was sent
# (epoch time)
std_msgs/Header header

# safety of the MAS:
#  - False if the MAS has a UAV non conforming/uninvolved,
#  - True otherwise
bool safe

# list of UAVs' description
digitaleye_msgs/UavIntReport[] uavs

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: digitaleye_msgs/UavIntReport
# Generic internal UAV report

# information on the time at which the object
# was reported (epoch time) and its reference frame
std_msgs/Header header

# list of internal metric(s), using UAV_INT_ constants 
digitaleye_msgs/Metric[] uav_metric

# list of point(s) linked to msg_type
digitaleye_msgs/Flightpath flight_path

# Constants for Metric of uav_metric

# internal id, uint
string UAV_INT_ID = Internal ID

# internal status: STATUS_UNKNOWN,
# STATUS_BOOKED, STATUS_HANDOVER_AIR, 
# STATUS_HANDOVER_GROUND, STATUS_TAKE_OFF_PREP
# STATUS_TAKING_OFF, STATUS_LANDING
# STATUS_FLYING_IN, STATUS_FLYING_OUT
# STATUS_HELD_FLY_IN, STATUS_HELD_FLY_OUT
# STATUS_HELD_TAKE_OFF, STATUS_HELD_LANDING
# STATUS_LANDED, STATUS_EXITING
string UAV_INT_STATUS = Internal status

# conformance status:
# CONF_UNKNOWN, CONF_KO_UNKNOWN_UAV
# CONF_WAITING_ENTRY, CONF_KO_AIR_ENTRY
# CONF_OK_AIR_ENTRY, CONF_KO_GROUND_ENTRY
# CONF_OK_GROUND_ENTRY, CONF_KO_FLIGHT_PATH
# CONF_OK_FLIGHT_PATH, CONF_READY_LAND
# CONF_READY_FLY_OUT
string UAV_INT_CONF_STATUS = Conformance status

================================================================================
MSG: digitaleye_msgs/Metric
# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value

================================================================================
MSG: digitaleye_msgs/Flightpath
# Fligh path definition

# TOLZ id (0 = N/A)
uint32 tolz_id

# list of flight point(s)
digitaleye_msgs/Flightpoint[] flight_points

================================================================================
MSG: digitaleye_msgs/Flightpoint
# Flight point definition

# local coordinates of point (meters)
geometry_msgs/Point coord

# desired speed to reach this point (m/s)
float32 speed

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z
"""
  __slots__ = ['header','safe','uavs']
  _slot_types = ['std_msgs/Header','bool','digitaleye_msgs/UavIntReport[]']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       header,safe,uavs

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(UavIntReportList, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.safe is None:
        self.safe = False
      if self.uavs is None:
        self.uavs = []
    else:
      self.header = std_msgs.msg.Header()
      self.safe = False
      self.uavs = []

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.safe
      buff.write(_get_struct_B().pack(_x))
      length = len(self.uavs)
      buff.write(_struct_I.pack(length))
      for val1 in self.uavs:
        _v1 = val1.header
        _x = _v1.seq
        buff.write(_get_struct_I().pack(_x))
        _v2 = _v1.stamp
        _x = _v2
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _x = _v1.frame_id
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(val1.uav_metric)
        buff.write(_struct_I.pack(length))
        for val2 in val1.uav_metric:
          _x = val2.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val2.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _v3 = val1.flight_path
        _x = _v3.tolz_id
        buff.write(_get_struct_I().pack(_x))
        length = len(_v3.flight_points)
        buff.write(_struct_I.pack(length))
        for val3 in _v3.flight_points:
          _v4 = val3.coord
          _x = _v4
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = val3.speed
          buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.uavs is None:
        self.uavs = None
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 1
      (self.safe,) = _get_struct_B().unpack(str[start:end])
      self.safe = bool(self.safe)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.uavs = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.UavIntReport()
        _v5 = val1.header
        start = end
        end += 4
        (_v5.seq,) = _get_struct_I().unpack(str[start:end])
        _v6 = _v5.stamp
        _x = _v6
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v5.frame_id = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v5.frame_id = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.uav_metric = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.value = str[start:end]
          val1.uav_metric.append(val2)
        _v7 = val1.flight_path
        start = end
        end += 4
        (_v7.tolz_id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v7.flight_points = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Flightpoint()
          _v8 = val3.coord
          _x = _v8
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 4
          (val3.speed,) = _get_struct_f().unpack(str[start:end])
          _v7.flight_points.append(val3)
        self.uavs.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.safe
      buff.write(_get_struct_B().pack(_x))
      length = len(self.uavs)
      buff.write(_struct_I.pack(length))
      for val1 in self.uavs:
        _v9 = val1.header
        _x = _v9.seq
        buff.write(_get_struct_I().pack(_x))
        _v10 = _v9.stamp
        _x = _v10
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _x = _v9.frame_id
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(val1.uav_metric)
        buff.write(_struct_I.pack(length))
        for val2 in val1.uav_metric:
          _x = val2.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val2.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _v11 = val1.flight_path
        _x = _v11.tolz_id
        buff.write(_get_struct_I().pack(_x))
        length = len(_v11.flight_points)
        buff.write(_struct_I.pack(length))
        for val3 in _v11.flight_points:
          _v12 = val3.coord
          _x = _v12
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = val3.speed
          buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.uavs is None:
        self.uavs = None
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 1
      (self.safe,) = _get_struct_B().unpack(str[start:end])
      self.safe = bool(self.safe)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.uavs = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.UavIntReport()
        _v13 = val1.header
        start = end
        end += 4
        (_v13.seq,) = _get_struct_I().unpack(str[start:end])
        _v14 = _v13.stamp
        _x = _v14
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v13.frame_id = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v13.frame_id = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.uav_metric = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.value = str[start:end]
          val1.uav_metric.append(val2)
        _v15 = val1.flight_path
        start = end
        end += 4
        (_v15.tolz_id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v15.flight_points = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Flightpoint()
          _v16 = val3.coord
          _x = _v16
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 4
          (val3.speed,) = _get_struct_f().unpack(str[start:end])
          _v15.flight_points.append(val3)
        self.uavs.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_B = None
def _get_struct_B():
    global _struct_B
    if _struct_B is None:
        _struct_B = struct.Struct("<B")
    return _struct_B
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f
